mailr21930 - /trunk/specific_analyses/relax_disp/optimisation.py


Others Months | Index by Date | Thread Index
>>   [Date Prev] [Date Next] [Thread Prev] [Thread Next]

Header


Content

Posted by edward on December 10, 2013 - 11:58:
Author: bugman
Date: Tue Dec 10 11:58:55 2013
New Revision: 21930

URL: http://svn.gna.org/viewcvs/relax?rev=21930&view=rev
Log:
Bug fix for the dispersion grid_search_setup() optimisation function.

This function was not updated for the recent addition of the spin-lock or 
hard pulse offset
dimension in the specific_analyses.relax_disp.disp_data module (and hence all 
structures used by the
dispersion target functions).  The loop_exp_frq_point() function call has 
been replaced by a
loop_exp_frq_offset_point() function call to allow the 'R2eff' model 
parameters to be looped over.

For more details, see the thread 
http://thread.gmane.org/gmane.science.nmr.relax.scm/19685.  This
solution was mentioned at 
http://thread.gmane.org/gmane.science.nmr.relax.scm/19685/focus=4859.


Modified:
    trunk/specific_analyses/relax_disp/optimisation.py

Modified: trunk/specific_analyses/relax_disp/optimisation.py
URL: 
http://svn.gna.org/viewcvs/relax/trunk/specific_analyses/relax_disp/optimisation.py?rev=21930&r1=21929&r2=21930&view=diff
==============================================================================
--- trunk/specific_analyses/relax_disp/optimisation.py (original)
+++ trunk/specific_analyses/relax_disp/optimisation.py Tue Dec 10 11:58:55 
2013
@@ -35,7 +35,7 @@
 from lib.errors import RelaxError
 from lib.text.sectioning import subsection
 from multi import Memo, Result_command, Slave_command
-from specific_analyses.relax_disp.disp_data import has_disp_data, 
has_proton_mmq_cpmg, loop_exp, loop_exp_frq, loop_exp_frq_point, loop_frq, 
loop_offset, pack_back_calc_r2eff, return_cpmg_frqs, 
return_index_from_disp_point, return_index_from_exp_type, 
return_index_from_frq, return_offset_data, return_param_key_from_data, 
return_r1_data, return_r2eff_arrays, return_spin_lock_nu1, 
return_value_from_frq_index
+from specific_analyses.relax_disp.disp_data import has_disp_data, 
has_proton_mmq_cpmg, loop_exp, loop_exp_frq, loop_exp_frq_offset_point, 
loop_frq, loop_offset, pack_back_calc_r2eff, return_cpmg_frqs, 
return_index_from_disp_point, return_index_from_exp_type, 
return_index_from_frq, return_offset_data, return_param_key_from_data, 
return_r1_data, return_r2eff_arrays, return_spin_lock_nu1, 
return_value_from_frq_index
 from specific_analyses.relax_disp.parameters import assemble_param_vector, 
assemble_scaling_matrix, disassemble_param_vector, linear_constraints, 
loop_parameters, param_conversion, param_num
 from specific_analyses.relax_disp.variables import EXP_TYPE_CPMG_PROTON_MQ, 
EXP_TYPE_CPMG_PROTON_SQ, EXP_TYPE_LIST_CPMG, MODEL_CR72, MODEL_CR72_FULL, 
MODEL_DPL94, MODEL_LIST_MMQ, MODEL_LM63, MODEL_M61, MODEL_M61B, MODEL_MP05, 
MODEL_NS_R1RHO_2SITE, MODEL_TAP03, MODEL_TP02
 from target_functions.relax_disp import Dispersion
@@ -179,8 +179,9 @@
 
         # The R2eff model.
         if cdp.model_type == 'R2eff':
-            # Loop over each spectrometer frequency and dispersion point.
-            for exp_type, frq, point in loop_exp_frq_point():
+            # Loop over each experiment type, spectrometer frequency, offset 
and dispersion point.
+            for exp_type, frq, offset, point in loop_exp_frq_offset_point():
+                print exp_type, frq, point
                 # Loop over the parameters.
                 for param_name, param_index, si, r20_key in 
loop_parameters(spins=spins):
                     # R2eff relaxation rate (from 1 to 40 s^-1).
@@ -278,6 +279,9 @@
     # Diagonal scaling of minimisation options.
     lower_new = []
     upper_new = []
+    print lower
+    print upper
+    print scaling_matrix
     for i in range(n):
         lower_new.append(lower[i] / scaling_matrix[i, i])
         upper_new.append(upper[i] / scaling_matrix[i, i])




Related Messages


Powered by MHonArc, Updated Tue Dec 10 12:20:02 2013